import {expect} from 'chai'
import sinon from 'sinon'
import jsCookie from 'js-cookie'
import loadCookies from '../../src/navOrigen/loadCookies'

describe('#loadCookies', () => {
  let jsCookieStub
  beforeEach(() => {
    jsCookieStub = sinon.stub(jsCookie, 'set')
  })

  afterEach(() => {
    jsCookieStub.restore()
  })

  it('should not loadCookies when navOrigen is not present', () => {
    loadCookies('anyhostname', 'randomKey=randomValue')

    sinon.assert.callCount(jsCookieStub, 0)
  })

  it('should loadCookies with only default navOrigen', () => {
    loadCookies('subdomain.domain.com', 'navOrigen=value')

    sinon.assert.callCount(jsCookieStub, 3)

    expect(jsCookieStub.getCall(0).args[0]).to.equal(`navOrigen`)
    expect(jsCookieStub.getCall(0).args[1]).to.equal(`value`)
    expect(jsCookieStub.getCall(0).args[2]).to.deep.equal({
      expires: 1,
      domain: '.domain.com'
    })
    expect(jsCookieStub.getCall(1).args[0]).to.equal(`navOrigenMes`)
    expect(jsCookieStub.getCall(1).args[1]).to.equal(`value`)
    expect(jsCookieStub.getCall(1).args[2]).to.deep.equal({
      expires: 30,
      domain: '.domain.com'
    })
    expect(jsCookieStub.getCall(2).args[0]).to.equal(`navOrigenSesion`)
    expect(jsCookieStub.getCall(2).args[1]).to.equal(`value`)
    expect(jsCookieStub.getCall(2).args[2]).to.deep.equal({
      expires: undefined,
      domain: '.domain.com'
    })
  })

  it('should loadCookies with custom navOrigen', () => {
    loadCookies('subdomain.domain.com', 'navOrigen=caInscInt|cutomValue')

    sinon.assert.callCount(jsCookieStub, 3)

    expect(jsCookieStub.getCall(0).args[0]).to.equal(`caInscInt`)
    expect(jsCookieStub.getCall(0).args[1]).to.equal(`cutomValue`)
    expect(jsCookieStub.getCall(0).args[2]).to.deep.equal({
      expires: 1,
      domain: '.domain.com'
    })
    expect(jsCookieStub.getCall(1).args[0]).to.equal(`caInscIntMes`)
    expect(jsCookieStub.getCall(1).args[1]).to.equal(`cutomValue`)
    expect(jsCookieStub.getCall(1).args[2]).to.deep.equal({
      expires: 30,
      domain: '.domain.com'
    })
    expect(jsCookieStub.getCall(2).args[0]).to.equal(`caInscIntSesion`)
    expect(jsCookieStub.getCall(2).args[1]).to.equal(`cutomValue`)
    expect(jsCookieStub.getCall(2).args[2]).to.deep.equal({
      expires: undefined,
      domain: '.domain.com'
    })
  })

  it('should loadCookies with custom navOrigen with pipe not decoded', () => {
    loadCookies('subdomain.domain.com', 'navOrigen=caInscInt%7CcutomValue')

    sinon.assert.callCount(jsCookieStub, 3)

    expect(jsCookieStub.getCall(0).args[0]).to.equal(`caInscInt`)
    expect(jsCookieStub.getCall(0).args[1]).to.equal(`cutomValue`)
    expect(jsCookieStub.getCall(0).args[2]).to.deep.equal({
      expires: 1,
      domain: '.domain.com'
    })
    expect(jsCookieStub.getCall(1).args[0]).to.equal(`caInscIntMes`)
    expect(jsCookieStub.getCall(1).args[1]).to.equal(`cutomValue`)
    expect(jsCookieStub.getCall(1).args[2]).to.deep.equal({
      expires: 30,
      domain: '.domain.com'
    })
    expect(jsCookieStub.getCall(2).args[0]).to.equal(`caInscIntSesion`)
    expect(jsCookieStub.getCall(2).args[1]).to.equal(`cutomValue`)
    expect(jsCookieStub.getCall(2).args[2]).to.deep.equal({
      expires: undefined,
      domain: '.domain.com'
    })
  })

  it('should loadCookies with two navOrigens', () => {
    loadCookies(
      'subdomain.domain.com',
      'navOrigen=value&navOrigen=caInscInt|cutomValue'
    )

    sinon.assert.callCount(jsCookieStub, 6)

    expect(jsCookieStub.getCall(0).args[0]).to.equal(`navOrigen`)
    expect(jsCookieStub.getCall(0).args[1]).to.equal(`value`)
    expect(jsCookieStub.getCall(0).args[2]).to.deep.equal({
      expires: 1,
      domain: '.domain.com'
    })
    expect(jsCookieStub.getCall(1).args[0]).to.equal(`navOrigenMes`)
    expect(jsCookieStub.getCall(1).args[1]).to.equal(`value`)
    expect(jsCookieStub.getCall(1).args[2]).to.deep.equal({
      expires: 30,
      domain: '.domain.com'
    })
    expect(jsCookieStub.getCall(2).args[0]).to.equal(`navOrigenSesion`)
    expect(jsCookieStub.getCall(2).args[1]).to.equal(`value`)
    expect(jsCookieStub.getCall(2).args[2]).to.deep.equal({
      expires: undefined,
      domain: '.domain.com'
    })

    expect(jsCookieStub.getCall(3).args[0]).to.equal(`caInscInt`)
    expect(jsCookieStub.getCall(3).args[1]).to.equal(`cutomValue`)
    expect(jsCookieStub.getCall(3).args[2]).to.deep.equal({
      expires: 1,
      domain: '.domain.com'
    })
    expect(jsCookieStub.getCall(4).args[0]).to.equal(`caInscIntMes`)
    expect(jsCookieStub.getCall(4).args[1]).to.equal(`cutomValue`)
    expect(jsCookieStub.getCall(4).args[2]).to.deep.equal({
      expires: 30,
      domain: '.domain.com'
    })
    expect(jsCookieStub.getCall(5).args[0]).to.equal(`caInscIntSesion`)
    expect(jsCookieStub.getCall(5).args[1]).to.equal(`cutomValue`)
    expect(jsCookieStub.getCall(5).args[2]).to.deep.equal({
      expires: undefined,
      domain: '.domain.com'
    })
  })

  it('should loadCookies with two navOrigens with question mark', () => {
    loadCookies(
      'subdomain.domain.com',
      '?navOrigen=value&navOrigen=caInscInt|cutomValue'
    )

    sinon.assert.callCount(jsCookieStub, 6)

    expect(jsCookieStub.getCall(0).args[0]).to.equal(`navOrigen`)
    expect(jsCookieStub.getCall(0).args[1]).to.equal(`value`)
    expect(jsCookieStub.getCall(0).args[2]).to.deep.equal({
      expires: 1,
      domain: '.domain.com'
    })
    expect(jsCookieStub.getCall(1).args[0]).to.equal(`navOrigenMes`)
    expect(jsCookieStub.getCall(1).args[1]).to.equal(`value`)
    expect(jsCookieStub.getCall(1).args[2]).to.deep.equal({
      expires: 30,
      domain: '.domain.com'
    })
    expect(jsCookieStub.getCall(2).args[0]).to.equal(`navOrigenSesion`)
    expect(jsCookieStub.getCall(2).args[1]).to.equal(`value`)
    expect(jsCookieStub.getCall(2).args[2]).to.deep.equal({
      expires: undefined,
      domain: '.domain.com'
    })

    expect(jsCookieStub.getCall(3).args[0]).to.equal(`caInscInt`)
    expect(jsCookieStub.getCall(3).args[1]).to.equal(`cutomValue`)
    expect(jsCookieStub.getCall(3).args[2]).to.deep.equal({
      expires: 1,
      domain: '.domain.com'
    })
    expect(jsCookieStub.getCall(4).args[0]).to.equal(`caInscIntMes`)
    expect(jsCookieStub.getCall(4).args[1]).to.equal(`cutomValue`)
    expect(jsCookieStub.getCall(4).args[2]).to.deep.equal({
      expires: 30,
      domain: '.domain.com'
    })
    expect(jsCookieStub.getCall(5).args[0]).to.equal(`caInscIntSesion`)
    expect(jsCookieStub.getCall(5).args[1]).to.equal(`cutomValue`)
    expect(jsCookieStub.getCall(5).args[2]).to.deep.equal({
      expires: undefined,
      domain: '.domain.com'
    })
  })
})
